package App::cpanmw;
use 5.008001;
use strict;
use warnings;

our $VERSION = "0.02";

1;
__END__

=encoding utf-8

=head1 NAME

App::cpanmw - the cpanm wrapper

=head1 DESCRIPTION

see L<cpanmw>

=head1 LICENSE

Copyright (C) 2014 KPEE.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

KPEE E<lt>kpee.cpanx@gmail.comE<gt>

=cut
